@@ -1,7 +1,7 @@
 /*
  * This file is part of Siril, an astronomy image processor.
  * Copyright (C) 2005-2011 Francois Meyer (dulle at free.fr)
- * Copyright (C) 2012-2017 team free-astro (see more in AUTHORS file)
+ * Copyright (C) 2012-2018 team free-astro (see more in AUTHORS file)
  * Reference site is https://free-astro.org/index.php/Siril
  *
  * Siril is free software: you can redistribute it and/or modify
@@ -34,6 +34,7 @@
 #include "core/siril.h"
 #include "core/proto.h"
 #include "gui/callbacks.h"
+#include "gui/progress_and_log.h"
 #include "algos/PSF.h"
 #include "algos/photometry.h"
 
@@ -376,9 +377,7 @@ static fitted_PSF *psf_minimiz_no_angle(gsl_matrix* z, double background,
 #if HAVE_GSL_1
 	gsl_multifit_covar(s->J, 0.0, covar);
 #elif HAVE_GSL_2
-	gsl_matrix * J;
-
-	J = gsl_matrix_alloc(n, p);
+	gsl_matrix * J = gsl_matrix_alloc(n, p);
 
 	gsl_multifit_fdfsolver_jac(s, J);
 	gsl_multifit_covar(J, 0.0, covar);
