@@ -2,6 +2,9 @@
 #define PSF_H_
 
 #include <gsl/gsl_matrix.h>
+#include <algos/photometry.h>
+
+//in siril.h: typedef struct fwhm_struct fitted_PSF;
 
 struct fwhm_struct {
 	double B; /* average sky background value */
@@ -11,6 +14,8 @@ struct fwhm_struct {
 	double fwhmx, fwhmy; /* FWHM in x and y axis */
 	double angle; /* angle of the axis x,y with respect to the image's */
 	double mag; /* magnitude of the star : this parameter is not fitted but calculated with the vector G and the parameter B */
+	double s_mag; /* error on the magnitude */
+	photometry *phot; /* photometry data */
 	double xpos, ypos; /* position of the star in the image, not set by Minimization */
 	double rmse; /* RMSE of the minimization */
 
@@ -34,8 +39,8 @@ struct PSF_data {
 };
 
 double psf_get_fwhm(fits *, int, double *);
-fitted_PSF *psf_get_minimisation(fits *, int, rectangle *);
-fitted_PSF *psf_global_minimisation(gsl_matrix *, double, int, gboolean);
+fitted_PSF *psf_get_minimisation(fits *, int, rectangle *, gboolean);
+fitted_PSF *psf_global_minimisation(gsl_matrix *, double, int, gboolean, gboolean);
 void psf_display_result(fitted_PSF *, rectangle *);
 void psf_update_units(fits*, fitted_PSF**);
 
