@@ -1,7 +1,7 @@
 /*
  * This file is part of Siril, an astronomy image processor.
  * Copyright (C) 2005-2011 Francois Meyer (dulle at free.fr)
- * Copyright (C) 2012-2017 team free-astro (see more in AUTHORS file)
+ * Copyright (C) 2012-2018 team free-astro (see more in AUTHORS file)
  * Reference site is https://free-astro.org/index.php/Siril
  *
  * Siril is free software: you can redistribute it and/or modify
@@ -26,6 +26,7 @@
 #include "core/proto.h"
 #include "core/processing.h"
 #include "gui/callbacks.h"
+#include "gui/progress_and_log.h"
 #include "io/single_image.h"
 #include "io/ser.h"
 #include "algos/cosmetic_correction.h"
@@ -323,7 +324,8 @@ void apply_cosmetic_to_sequence(struct cosmetic_data *cosme_args) {
 	args->save_hook = NULL;
 	args->image_hook = cosmetic_image_hook;
 	args->idle_function = NULL;
-	args->description = "Cosmetic Correction";
+	args->stop_on_error = FALSE;
+	args->description = _("Cosmetic Correction");
 	args->has_output = TRUE;
 	args->new_seq_prefix = cosme_args->seqEntry;
 	args->load_new_sequence = TRUE;
