@@ -1,7 +1,7 @@
 /*
  * This file is part of Siril, an astronomy image processor.
  * Copyright (C) 2005-2011 Francois Meyer (dulle at free.fr)
- * Copyright (C) 2012-2017 team free-astro (see more in AUTHORS file)
+ * Copyright (C) 2012-2018 team free-astro (see more in AUTHORS file)
  * Reference site is https://free-astro.org/index.php/Siril
  *
  * Siril is free software: you can redistribute it and/or modify
@@ -173,7 +173,7 @@ double QualityEstimate(fits *fit, int layer, int qtype) {
 		FILE *out;
 
 		sprintf(filename, "sample_%d.ppm", subsample);
-		out = fopen(filename, "wb");
+		out = g_fopen(filename, "wb");
 		if (out == NULL)
 		printf("Cannot write subsampled image %d\n", subsample);
 		else {
