@@ -1,7 +1,7 @@
 /*
  * This file is part of Siril, an astronomy image processor.
  * Copyright (C) 2005-2011 Francois Meyer (dulle at free.fr)
- * Copyright (C) 2012-2017 team free-astro (see more in AUTHORS file)
+ * Copyright (C) 2012-2018 team free-astro (see more in AUTHORS file)
  * Reference site is https://free-astro.org/index.php/Siril
  *
  * Siril is free software: you can redistribute it and/or modify
@@ -25,6 +25,7 @@
 
 #include "core/siril.h"
 #include "gui/callbacks.h"
+#include "gui/progress_and_log.h"
 #include "core/proto.h"
 #include "registration/registration.h"
 #include "io/sequence.h"
@@ -76,8 +77,8 @@ static void align_and_compose() {
 			for (channel = 0; channel < 3; channel++) {
 				if (seq && seq->regparam) {
 					WORD pixel;
-					int realX = x - seq->regparam[REGLAYER][channel].shiftx;
-					int realY = y - seq->regparam[REGLAYER][channel].shifty;
+					int realX = x - roundf_to_int(seq->regparam[REGLAYER][channel].shiftx);
+					int realY = y - roundf_to_int(seq->regparam[REGLAYER][channel].shifty);
 					if (realX < 0 || realX >= gfit.rx)
 						pixel = 0;
 					else if (realY < 0 || realY >= gfit.ry)
@@ -103,11 +104,14 @@ int rgb_align(int m) {
 	method = reg_methods[m];
 
 	regargs.seq = seq;
-	regargs.seq->nb_layers = 3;
+	regargs.seq->nb_layers = 1;
 	regargs.process_all_frames = TRUE;
 	get_the_registration_area(&regargs, method);
 	regargs.layer = REGLAYER;
+	regargs.follow_star = FALSE;
+	regargs.x2upscale = FALSE;
 	regargs.run_in_thread = FALSE;
+	com.run_thread = TRUE;	// fix for the canceling check in processing
 
 	set_cursor_waiting(TRUE);
 	set_progress_bar_data(NULL, PROGRESS_RESET);
@@ -116,6 +120,7 @@ int rgb_align(int m) {
 	else
 		set_progress_bar_data(_("Registration complete."), PROGRESS_DONE);
 	set_cursor_waiting(FALSE);
+	com.run_thread = FALSE;	// fix for the canceling check in processing
 
 	align_and_compose();
 
