@@ -27,6 +27,9 @@ int	process_savebmp(int nb);
 #ifdef HAVE_LIBJPEG
 int	process_savejpg(int nb);
 #endif
+#ifdef HAVE_LIBPNG
+int	process_savepng(int nb);
+#endif
 #ifdef HAVE_LIBTIFF
 int	process_savetif(int nb);
 #endif
@@ -74,10 +77,9 @@ int	process_cdg(int nb);
 int 	process_clearstar(int nb);
 int	process_mirrorx(int nb);
 int	process_mirrory(int nb);
-#ifdef HAVE_OPENCV
 int	process_resample(int nb);
+int	process_rl(int nb);
 int	process_rotate(int nb);
-#endif
 int	process_rotatepi(int nb);
 int 	process_psf(int nb);
 int	process_seq_psf(int nb);
