@@ -25,7 +25,7 @@
 #include <sys/stat.h>
 #include <gio/gio.h>
 #include <glib/gstdio.h>
-#ifdef WIN32
+#ifdef _WIN32
 #include <direct.h>
 #include <shlobj.h>
 #define DATADIR datadir
@@ -39,6 +39,7 @@
 #include "core/proto.h"
 #include "core/initfile.h"
 #include "gui/callbacks.h"
+#include "gui/progress_and_log.h"
 
 #define CFG_FILE "siril.cfg"
 
@@ -61,9 +62,13 @@ static int readinitfile() {
 
 	/* Working directory */
 	if (config_lookup_string(&config, keywords[WD], &dir)) {
-		if (changedir(dir)) {
-			siril_log_message(
-					_("Reverting current working directory to startup directory, the saved directory is not available anymore\n"));
+		if (changedir(dir, NULL)) {
+			siril_log_message(_("Reverting current working directory to startup directory, "
+					"the saved directory is not available anymore\n"));
+			if (changedir(com.wd, NULL)) {
+				fprintf(stderr, "Could not change to start-up directory, aborting\n");
+				return 1;
+			}
 			set_GUI_CWD();
 			writeinitfile();
 		}
@@ -151,11 +156,11 @@ static int readinitfile() {
 	}
 	if (swap_dir && swap_dir[0] != '\0') {
 		if (com.swap_dir)
-			free(com.swap_dir);
-		com.swap_dir = strdup(swap_dir);
+			g_free(com.swap_dir);
+		com.swap_dir = g_strdup(swap_dir);
 	} else {
 		const char* sw_dir = g_get_tmp_dir();
-		com.swap_dir = strdup(sw_dir);
+		com.swap_dir = g_strdup(sw_dir);
 	}
 	if (extension && extension[0] != '\0') {
 		if (com.ext)
@@ -335,9 +340,9 @@ int writeinitfile() {
 	return 0;
 }
 
-#ifdef WIN32
+#ifdef _WIN32
 /* stolen from gimp which in turn stole from glib 2.35 */
-static gchar * get_special_folder(int csidl) {
+static gchar *get_special_folder(int csidl) {
 	wchar_t path[MAX_PATH + 1];
 	HRESULT hr;
 	LPITEMIDLIST pidl = NULL;
@@ -357,7 +362,7 @@ static gchar * get_special_folder(int csidl) {
 #endif
 
 int checkinitfile() {
-	char *home;
+	gchar *home = NULL;
 	struct stat sts;
 
 	// try to read the file given on command line
@@ -366,7 +371,7 @@ int checkinitfile() {
 	}
 
 	// no file given on command line, set initfile to default location
-#ifdef WIN32
+#ifdef _WIN32
 	home = g_build_filename (get_special_folder (CSIDL_APPDATA),
 			"siril", NULL);
 	if( g_mkdir_with_parents( home, 1 ) == 0 ) {
@@ -375,49 +380,55 @@ int checkinitfile() {
 		fprintf( stderr, "Failed to create homefolder %s!\n", com.initfile );
 	}
 #else
-	if ((home = getenv("HOME")) == NULL) {
+	const gchar *tmp = g_get_home_dir();
+	if (tmp == NULL) {
 		fprintf(stderr,
 				"Could not get the environment variable $HOME, no config file.\n");
 		return 1;
 	}
+	home = g_strdup(tmp);
 #endif
 
 #if (defined(__APPLE__) && defined(__MACH__))
 	fprintf(stderr, "Creating initfile in Application Support.\n");
 	gchar *homefolder;
-	homefolder = g_build_filename(getenv("HOME"),
-			"Library/Application Support/siril", NULL);
+	homefolder = g_build_filename(g_get_home_dir(),
+			"Library", "Application Support", "siril", NULL);
 	if (g_mkdir_with_parents(homefolder, 0755) == 0) {
 		com.initfile = g_build_filename(homefolder, CFG_FILE, NULL);
 		fprintf(stderr, "The initfile name is %s.\n", com.initfile);
 	} else {
 		fprintf(stderr, "Failed to create homefolder %s.\n", homefolder);
 	}
-	g_free(homefolder);
-#elif WIN32
+
+#elif defined (_WIN32)
 	com.initfile = g_build_filename(home, CFG_FILE, NULL);
 #else
-	com.initfile = malloc(strlen(home) + 20);
+	com.initfile = g_new(gchar, strlen(home) + 20);
 	sprintf(com.initfile, "%s/.siril/%s", home, CFG_FILE);
-#endif /* _APPLE__ */
+#endif
 	if (readinitfile()) {	// couldn't read it
 		char filename[255];
 
 		set_GUI_CWD();
 		// if that fails, check and create the default ini file
-		snprintf(filename, 255, "%s/.siril", home);
-		if (stat(filename, &sts) != 0) {
-			if (errno == ENOENT) {
-#ifdef WIN32
-				if (_mkdir(filename)) {
+#if (defined(__APPLE__) && defined(__MACH__))
+		snprintf(filename, 255, "%s", homefolder);
+		g_free(homefolder);
+#elif defined (_WIN32)
+		snprintf(filename, 255, "%s", home);
 #else
-				if (mkdir(filename, 0755)) {
+		snprintf(filename, 255, "%s/.siril", home);
 #endif
+		g_free(home);
+		if (g_stat(filename, &sts) != 0) {
+			if (errno == ENOENT) {
+				if (g_mkdir(filename, 0755)) {
 					fprintf(stderr, "Could not create dir %s, please check\n",
 							filename);
 					return 1;
 				}
-				com.swap_dir = strdup(g_get_tmp_dir());
+				com.swap_dir = g_strdup(g_get_tmp_dir());
 				com.ext = strdup(".fit");
 				return (writeinitfile());
 			}
@@ -430,7 +441,7 @@ int checkinitfile() {
 			return 1;
 		}
 
-		com.swap_dir = strdup(g_get_tmp_dir());
+		com.swap_dir = g_strdup(g_get_tmp_dir());
 		com.ext = strdup(".fit");
 		return (writeinitfile());
 	}
