@@ -74,8 +74,9 @@ gpointer generic_sequence_worker(gpointer p) {
 	if (args->filtering_criterion) {
 		index_mapping = malloc(nb_frames * sizeof(int));
 		for (input_idx = 0, frame = 0; input_idx < args->seq->number; input_idx++) {
-			if (!args->filtering_criterion(args->seq, input_idx, args->filtering_parameter))
+			if (!args->filtering_criterion(args->seq, input_idx, args->filtering_parameter)) {
 				continue;
+			}
 			index_mapping[frame++] = input_idx;
 		}
 		if (frame != nb_frames) {
@@ -202,10 +203,10 @@ gpointer generic_sequence_worker(gpointer p) {
 		show_time(t_start, t_end);
 	}
 
-the_end:
 #ifdef _OPENMP
 	omp_destroy_lock(&args->lock);
 #endif
+the_end:
 	if (index_mapping) free(index_mapping);
 	if (args->finalize_hook && args->finalize_hook(args)) {
 		siril_log_message(_("Finalizing sequence processing failed.\n"));
