@@ -11,12 +11,16 @@ void clear_histograms();
 void set_histo_toggles_names();
 void erase_histo_display(cairo_t *cr, int width, int height);
 void display_histo(gsl_histogram *histo, cairo_t *cr, int layer, int width,
-		int height);
+		int height, double ZoomH, double zoomV);
 void reset_curors_and_values();
 void update_histo_mtf();
-void apply_mtf_to_fits(fits *fit);
+void apply_mtf_to_fits(fits *fit, double m, double lo, double hi);
 void apply_mtf_to_histo(gsl_histogram *histo, double norm, double m, double lo,
 		double hi);
 double MTF(double x, double m);
+double findMidtonesBalance(fits *fit, double *shadows, double *highlights) ;
+void on_scale_midtones_value_changed(GtkRange *range, gpointer user_data);
+void on_scale_shadows_value_changed(GtkRange *range, gpointer user_data);
+void on_scale_highlights_value_changed(GtkRange *range, gpointer user_data);
 
 #endif
