@@ -106,8 +106,24 @@ static double serTimestamp_toJulian(uint64_t timestamp) {
 	uint64_t t1970_ms = (timestamp - epochTicks) / 10000;
 	time_t secs = t1970_ms / 1000;
 	int ms = t1970_ms % 1000;
+#ifdef HAVE_GMTIME_R
+	struct tm t_;
+#endif
 
+#ifdef _WIN32
+	t = gmtime (&secs);
+#else
+#ifdef HAVE_GMTIME_R
+	t = gmtime_r (&secs, &t_);
+#else
 	t = gmtime(&secs);
+#endif /* HAVE_GMTIME_R */
+#endif /* _WIN32 */
+
+	/* If the gmtime() call has failed, "secs" is too big. */
+	if (t == NULL) {
+		return -1.0;
+	}
 
 	/* Get real year and month */
 	memset(&dt, 0, sizeof(dateTime));
@@ -262,7 +278,7 @@ static int lightCurve(pldata *plot, sequence *seq) {
 				"Please consider to install it before "
 				"trying to plot a graph of a variable star.\n"));
 
-		show_dialog(msg, _("Warning"), "gtk-dialog-warning");
+		show_dialog(msg, _("Warning"), "dialog-warning");
 		return -1;
 	}
 
@@ -358,10 +374,10 @@ static int lightCurve(pldata *plot, sequence *seq) {
 				"JD_UT V-C err");
 		if (!ret) {
 			char *msg = siril_log_message(_("%s has been saved.\n"), filename);
-			show_dialog(msg, _("Information"), "gtk-dialog-info");
+			show_dialog(msg, _("Information"), "dialog-information");
 		} else {
 			show_dialog(_("Something went wrong while saving plot"), _("Error"),
-					"gtk-dialog-error");
+					"dialog-error");
 		}
 		g_free(filename);
 	}
@@ -417,10 +433,10 @@ static int exportCSV(pldata *plot, sequence *seq) {
 	}
 	if (!ret) {
 		msg = siril_log_message(_("%s.csv has been saved.\n"), file);
-		show_dialog(msg, _("Information"), "gtk-dialog-info");
+		show_dialog(msg, _("Information"), "dialog-information");
 	} else {
 		show_dialog(_("Something went wrong while saving plot"), _("Error"),
-				"gtk-dialog-error");
+				"dialog-error");
 	}
 	return 0;
 }
