@@ -77,7 +77,10 @@ char *filter_pattern[] = {
 	"RGGB",
 	"BGGR",
 	"GBRG",
-	"GRBG"
+	"GRBG",
+	"RBGBRGGGRGGBGGBGGRBRGRBGGGBGGRGGRGGB", /* XTRANS */
+	"GBGGRGRGRBGBGBGGRGGRGGBGBGBRGRGRGGBG",
+	"GGRGGBGGBGGRBRGRBGGGBGGRGGRGGBRBGBRG"
 };
 
 enum {
@@ -518,13 +521,13 @@ void on_convert_button_clicked(GtkButton *button, gpointer user_data) {
 	char *tmpmsg;
 	if (!com.wd) {
 		tmpmsg = siril_log_message(_("Conversion: no working directory set.\n"));
-		show_dialog(tmpmsg, _("Warning"), "gtk-dialog-warning");
+		show_dialog(tmpmsg, _("Warning"), "dialog-warning");
 		set_cursor_waiting(FALSE);
 		return;
 	}
 	if((dir = g_dir_open(com.wd, 0, &error)) == NULL){
 		tmpmsg = siril_log_message(_("Conversion: error opening working directory %s.\n"), com.wd);
-		show_dialog(tmpmsg, _("Error"), "gtk-dialog-error");
+		show_dialog(tmpmsg, _("Error"), "dialog-error");
 		fprintf (stderr, "Conversion: %s\n", error->message);
 		set_cursor_waiting(FALSE);
 		return ;
@@ -594,7 +597,7 @@ static gpointer convert_thread_worker(gpointer p) {
 				"If the file type you are trying to load is listed in supported "
 				"formats, you may notify the developpers that the extension you are "
 				"trying to use should be recognized for this type."), src_ext);
-			show_dialog(msg, _("Error"), "gtk-dialog-error");
+			show_dialog(msg, _("Error"), "dialog-error");
 			break;	// avoid 100 error popups
 		}
 
@@ -766,7 +769,7 @@ int save_to_target_fits(fits *fit, const char *dest_filename) {
 static int retrieveBayerPattern(char *bayer) {
 	int i;
 
-	for (i = BAYER_FILTER_MIN; i < BAYER_FILTER_MAX; i++) {
+	for (i = 0; i < (sizeof(filter_pattern) / sizeof(char *)); i++) {
 		if (g_ascii_strcasecmp(bayer, filter_pattern[i]) == 0) {
 			return i;
 		}
@@ -793,20 +796,29 @@ int debayer_if_needed(image_type imagetype, fits *fit, gboolean compatibility) {
 		if (com.debayer.use_bayer_header) {
 			sensor_pattern bayer;
 			bayer = retrieveBayerPattern(fit->bayer_pattern);
-			if (bayer != com.debayer.bayer_pattern) {
-				if (bayer == BAYER_FILTER_NONE) {
-					siril_log_color_message(_("No Bayer pattern found in the header file.\n"), "red");
-				}
-				else {
-					siril_log_color_message(_("Bayer pattern found in header (%s) is different"
-							" from Bayer pattern in settings (%s). Overriding settings.\n"),
-							"red", filter_pattern[bayer], filter_pattern[com.debayer.bayer_pattern]);
-					com.debayer.bayer_pattern = bayer;
+
+			if (bayer <= BAYER_FILTER_MAX) {
+				if (bayer != com.debayer.bayer_pattern) {
+					if (bayer == BAYER_FILTER_NONE) {
+						siril_log_color_message(_("No Bayer pattern found in the header file.\n"), "red");
+					}
+					else {
+						siril_log_color_message(_("Bayer pattern found in header (%s) is different"
+								" from Bayer pattern in settings (%s). Overriding settings.\n"),
+								"red", filter_pattern[bayer], filter_pattern[com.debayer.bayer_pattern]);
+						com.debayer.bayer_pattern = bayer;
+					}
 				}
+			} else { /* FIXME: XTRANS CASE. TESTED FOR ONE FILE */
+				com.debayer.bayer_pattern = XTRANS_FILTER;
+				com.debayer.bayer_inter = XTRANS;
+				siril_log_color_message(_("XTRANS Sensor detected. Using special algorithm.\n"), "red");
 			}
 		}
-		if (com.debayer.bayer_pattern >= 0)
+		if (com.debayer.bayer_pattern >= BAYER_FILTER_MIN
+				&& com.debayer.bayer_pattern <= BAYER_FILTER_MAX) {
 			siril_log_message(_("Filter Pattern: %s\n"), filter_pattern[com.debayer.bayer_pattern]);
+		}
 
 		if (debayer(fit, com.debayer.bayer_inter)) {
 			siril_log_message(_("Cannot perform debayering\n"));
