@@ -49,7 +49,7 @@ int readbmp(const char *name, fits *fit) {
 
 	if ((fd = g_open(name, O_RDONLY | O_BINARY, 0)) == -1) {
 		msg = siril_log_message(_("Error opening BMP.\n"));
-		show_dialog(msg, _("Error"), "gtk-dialog-error");
+		show_dialog(msg, _("Error"), "dialog-error");
 		return -1;
 	}
 
@@ -104,7 +104,7 @@ int readbmp(const char *name, fits *fit) {
 		msg =
 				siril_log_message(
 						_("Sorry but Siril cannot open this kind of BMP. Try to convert it before.\n"));
-		show_dialog(msg, _("Error"), "gtk-dialog-error");
+		show_dialog(msg, _("Error"), "dialog-error");
 	}
 	free(buf);
 	char *basename = g_path_get_basename(name);
@@ -167,18 +167,17 @@ int savebmp(const char *name, fits *fit) {
 	bmpinfoheader[27] = (unsigned char) (datasize >> 24);
 
 	char *filename = strdup(name);
-	if (!ends_with(filename, ".tif") && (!ends_with(filename, ".tiff"))) {
-		filename = str_append(&filename, ".tif");
+	if (!ends_with(filename, ".bmp")) {
+		filename = str_append(&filename, ".bmp");
 	}
 
 	f = g_fopen(filename, "wb");
 	if (f == NULL) {
 		char *msg = siril_log_message(_("Can't create BMP file.\n"));
-		show_dialog(msg, _("Error"), "gtk-dialog-error");
+		show_dialog(msg, _("Error"), "dialog-error");
 		free(filename);
 		return 1;
 	}
-	free(filename);
 
 	fwrite(bmpfileheader, sizeof(bmpfileheader), 1, f);
 	fwrite(bmpinfoheader, sizeof(bmpinfoheader), 1, f);
@@ -212,8 +211,9 @@ int savebmp(const char *name, fits *fit) {
 		}
 	}
 	fclose(f);
-	siril_log_message(_("Saving BMP: file %s, %ld layer(s), %ux%u pixels\n"), name,
+	siril_log_message(_("Saving BMP: file %s, %ld layer(s), %ux%u pixels\n"), filename,
 			fit->naxes[2], fit->rx, fit->ry);
+	free(filename);
 	return 0;
 }
 
@@ -343,7 +343,7 @@ int import_pnm_to_fits(const char *filename, fits *fit) {
 
 	if ((fd = g_fopen(filename, "rb")) == NULL) {
 		msg = siril_log_message(_("Sorry but Siril cannot open this file.\n"));
-		show_dialog(msg, _("Error"), "gtk-dialog-error");
+		show_dialog(msg, _("Error"), "dialog-error");
 		return -1;
 	}
 	if (fgets(buf, 256, fd) == NULL) {
@@ -355,7 +355,7 @@ int import_pnm_to_fits(const char *filename, fits *fit) {
 		msg = siril_log_message(
 				_("Wrong magic cookie in PNM file, ASCII types and"
 						" b&w bitmaps are not supported.\n"));
-		show_dialog(msg, _("Error"), "gtk-dialog-error");
+		show_dialog(msg, _("Error"), "dialog-error");
 		fclose(fd);
 		return -1;
 	}
@@ -438,7 +438,7 @@ int import_pnm_to_fits(const char *filename, fits *fit) {
 		}
 		if (fread(tmpbuf, stride, fit->ry, fd) < fit->ry) {
 			msg = siril_log_message(_("Error reading 8-bit PPM image data.\n"));
-			show_dialog(msg, _("Error"), "gtk-dialog-error");
+			show_dialog(msg, _("Error"), "dialog-error");
 			fclose(fd);
 			free(tmpbuf);
 			free(fit->data);
@@ -470,7 +470,7 @@ int import_pnm_to_fits(const char *filename, fits *fit) {
 			if (fread(fit->data, stride, fit->ry, fd) < fit->ry) {
 				msg = siril_log_message(
 						_("Error reading 16-bit gray PPM image data.\n"));
-				show_dialog(msg, _("Error"), "gtk-dialog-error");
+				show_dialog(msg, _("Error"), "dialog-error");
 				fclose(fd);
 				free(fit->data);
 				fit->data = NULL;
@@ -503,7 +503,7 @@ int import_pnm_to_fits(const char *filename, fits *fit) {
 			if (fread(tmpbuf, stride, fit->ry, fd) < fit->ry) {
 				msg = siril_log_message(
 						_("Error reading 16-bit color PPM image data.\n"));
-				show_dialog(msg, _("Error"), "gtk-dialog-error");
+				show_dialog(msg, _("Error"), "dialog-error");
 				fclose(fd);
 				free(tmpbuf);
 				free(fit->data);
@@ -519,7 +519,7 @@ int import_pnm_to_fits(const char *filename, fits *fit) {
 	} else {
 		msg = siril_log_message(_("Not handled max value for PNM: %d.\n"),
 				max_val);
-		show_dialog(msg, _("Error"), "gtk-dialog-error");
+		show_dialog(msg, _("Error"), "dialog-error");
 		fclose(fd);
 		return -1;
 	}
@@ -696,7 +696,7 @@ static int _pic_read_header(struct pic_struct *pic_file) {
 		char *msg =
 				siril_log_message(
 						_("Wrong magic cookie in PIC file. This image is not supported.\n"));
-		show_dialog(msg, _("Error"), "gtk-dialog-error");
+		show_dialog(msg, _("Error"), "dialog-error");
 		return -1;
 	}
 
@@ -744,7 +744,7 @@ int readpic(const char *name, fits *fit) {
 	if ((pic_file->fd = g_open(name, O_RDONLY | O_BINARY, 0)) == -1) {
 		msg = siril_log_message(
 				_("Sorry but Siril cannot open the PIC file: %s.\n"), name);
-		show_dialog(msg, _("Error"), "gtk-dialog-error");
+		show_dialog(msg, _("Error"), "dialog-error");
 		free(pic_file);
 		return -1;
 	}
@@ -782,7 +782,7 @@ int readpic(const char *name, fits *fit) {
 	default:
 		retval = -1;
 		msg = siril_log_message(_("Sorry but Siril cannot open this file.\n"));
-		show_dialog(msg, _("Error"), "gtk-dialog-error");
+		show_dialog(msg, _("Error"), "dialog-error");
 	}
 
 	char *basename = g_path_get_basename(name);
