@@ -70,7 +70,7 @@ static int readtifstrip(TIFF* tif, uint32 width, uint32 height, uint16 nsamples,
 	WORD *gbuf[3] = {*data, *data, *data};
 	if (nsamples == 4) {
 		msg = siril_log_message(_("Alpha channel is ignored.\n"));
-		show_dialog(msg, _("Warning"), "gtk-dialog-warning");
+		show_dialog(msg, _("Warning"), "dialog-warning");
 	}
 	if ((nsamples == 3) || (nsamples == 4)) {
 		gbuf[1] = *data + npixels;
@@ -86,7 +86,7 @@ static int readtifstrip(TIFF* tif, uint32 width, uint32 height, uint16 nsamples,
 			case PLANARCONFIG_CONTIG:
 				if (TIFFReadEncodedStrip(tif, TIFFComputeStrip(tif, row, 0), buf, nrow*scanline) < 0){
 					msg = siril_log_message(_("An unexpected error was encountered while trying to read the file.\n"));
-					show_dialog(msg, _("Error"), "gtk-dialog-error");
+					show_dialog(msg, _("Error"), "dialog-error");
 					retval = -1;
 					break;
 				}
@@ -104,7 +104,7 @@ static int readtifstrip(TIFF* tif, uint32 width, uint32 height, uint16 nsamples,
 				for (j=0; j<nsamples; j++){	//loop on the layer
 					if (TIFFReadEncodedStrip(tif, TIFFComputeStrip(tif, row, j), buf, nrow*scanline) < 0){
 						msg = siril_log_message(_("An unexpected error was encountered while trying to read the file.\n"));
-						show_dialog(msg, _("Error"), "gtk-dialog-error");
+						show_dialog(msg, _("Error"), "dialog-error");
 						retval = -1;
 						break;
 					}
@@ -114,7 +114,7 @@ static int readtifstrip(TIFF* tif, uint32 width, uint32 height, uint16 nsamples,
 				break;
 			default:
 				msg = siril_log_message(_("Unknown TIFF file.\n"));
-				show_dialog(msg, _("Error"), "gtk-dialog-error");
+				show_dialog(msg, _("Error"), "dialog-error");
 				retval = -1;
 		}
 	}
@@ -156,7 +156,7 @@ static int readtif8bits(TIFF* tif, uint32 width, uint32 height, uint16 nsamples,
 		}
 		else {
 			msg = siril_log_message(_("An unexpected error was encountered while trying to read the file.\n"));
-			show_dialog(msg, _("Error"), "gtk-dialog-error");
+			show_dialog(msg, _("Error"), "dialog-error");
 			retval = -1;
 		}
 		_TIFFfree(raster);
@@ -226,7 +226,7 @@ int readtif(const char *name, fits *fit) {
 
 		default :
 			msg = siril_log_message(_("Siril only works with 8/16-bit TIFF format.\n"));
-			show_dialog(msg, _("Warning"), "gtk-dialog-warning");
+			show_dialog(msg, _("Warning"), "dialog-warning");
 			retval = -1;
 	}
 	TIFFClose(tif);
@@ -288,11 +288,10 @@ int savetif(const char *name, fits *fit, uint16 bitspersample){
 
 	if (tif == NULL) {
 		msg = siril_log_message(_("Siril cannot create TIFF file.\n"));
-		show_dialog(msg, _("Error"), "gtk-dialog-error");
+		show_dialog(msg, _("Error"), "dialog-error");
 		free(filename);
 		return 1;
 	}
-	free(filename);
 	nsamples = (uint16) fit->naxes[2];
 	width = (uint32) fit->rx;
 	height = (uint32) fit->ry;
@@ -346,7 +345,8 @@ int savetif(const char *name, fits *fit, uint16 bitspersample){
 	else {
 		TIFFClose(tif);
 		msg = siril_log_message(_("TIFF file has unexpected number of channels (not 1 or 3).\n"));
-		show_dialog(msg, _("Error"), "gtk-dialog-error");
+		show_dialog(msg, _("Error"), "dialog-error");
+		free(filename);
 		return 1;
 	}
 
@@ -387,7 +387,8 @@ int savetif(const char *name, fits *fit, uint16 bitspersample){
 	mirrorx(fit, FALSE);
 	siril_log_message(
 			_("Saving TIFF: %d-bit file %s, %ld layer(s), %ux%u pixels\n"),
-			bitspersample, name, fit->naxes[2], fit->rx, fit->ry);
+			bitspersample, filename, fit->naxes[2], fit->rx, fit->ry);
+	free(filename);
 	return retval;
 }
 #endif	// HAVE_LIBTIFF
@@ -408,7 +409,7 @@ int readjpg(const char* name, fits *fit){
 
 	if ((f = g_fopen(name, "rb")) == NULL){
 		char *msg = siril_log_message(_("Sorry but Siril cannot open the file: %s.\n"), name);
-		show_dialog(msg, _("Error"), "gtk-dialog-error");
+		show_dialog(msg, _("Error"), "dialog-error");
 		return -1;
 	}
 	cinfo.err = jpeg_std_error(&jerr);
@@ -460,7 +461,7 @@ int readjpg(const char* name, fits *fit){
 	return cinfo.output_components;
 }
 
-int savejpg(char *name, fits *fit, int quality){
+int savejpg(const char *name, fits *fit, int quality){
 	FILE *f;
 	int i, j;
 	unsigned char red, blue, green;
@@ -481,11 +482,10 @@ int savejpg(char *name, fits *fit, int quality){
 	//## OPEN FILE FOR DATA DESTINATION:
 	if ((f = g_fopen(filename, "wb")) == NULL) {
 		char *msg = siril_log_message(_("Siril cannot create JPG file.\n"));
-		show_dialog(msg, _("Error"), "gtk-dialog-error");
+		show_dialog(msg, _("Error"), "dialog-error");
 		free(filename);
 		return 1;
 	}
-	free(filename);
 	jpeg_stdio_dest(&cinfo, f);
 
 	//## SET PARAMETERS FOR COMPRESSION:
@@ -546,7 +546,8 @@ int savejpg(char *name, fits *fit, int quality){
 	jpeg_destroy_compress(&cinfo);
 	free(image_buffer);
 	siril_log_message(_("Saving JPG: file %s, quality=%d%%, %ld layer(s), %ux%u pixels\n"),
-						name, quality, fit->naxes[2], fit->rx, fit->ry);
+						filename, quality, fit->naxes[2], fit->rx, fit->ry);
+	free(filename);
 	return 0;
 }
 #endif	// HAVE_LIBJPEG
@@ -565,10 +566,11 @@ int readpng(const char *name, fits* fit) {
 	WORD *data;
 	FILE *f;
 
-	png_structp png = png_create_read_struct(PNG_LIBPNG_VER_STRING, NULL, NULL, NULL);
-	if(!png) {
+	png_structp png = png_create_read_struct(PNG_LIBPNG_VER_STRING, NULL, NULL,
+			NULL);
+	if (!png) {
 		char *msg = siril_log_message(_("Sorry but Siril cannot open the file: %s.\n"), name);
-		show_dialog(msg, _("Error"), "gtk-dialog-error");
+		show_dialog(msg, _("Error"), "dialog-error");
 		return -1;
 	}
 
@@ -589,87 +591,87 @@ int readpng(const char *name, fits* fit) {
 	bit_depth = png_get_bit_depth(png, info);
 
 	data = malloc(npixels * sizeof(WORD) * 3);
-	WORD *buf[3] = {data, data + npixels, data + npixels * 2};
+	WORD *buf[3] = { data, data + npixels, data + npixels * 2 };
 
-	if(color_type == PNG_COLOR_TYPE_PALETTE)
+	if (color_type == PNG_COLOR_TYPE_PALETTE)
 		png_set_palette_to_rgb(png);
 
 	// PNG_COLOR_TYPE_GRAY_ALPHA is always 8 or 16bit depth.
-	if(color_type == PNG_COLOR_TYPE_GRAY && bit_depth < 8)
+	if (color_type == PNG_COLOR_TYPE_GRAY && bit_depth < 8)
 		png_set_expand_gray_1_2_4_to_8(png);
 
-	if(png_get_valid(png, info, PNG_INFO_tRNS))
+	if (png_get_valid(png, info, PNG_INFO_tRNS))
 		png_set_tRNS_to_alpha(png);
 
 	// These color_type don't have an alpha channel then fill it with 0xff.
-	if(color_type == PNG_COLOR_TYPE_RGB || color_type == PNG_COLOR_TYPE_GRAY ||
-			color_type == PNG_COLOR_TYPE_PALETTE)
+	if (color_type == PNG_COLOR_TYPE_RGB || color_type == PNG_COLOR_TYPE_GRAY
+			|| color_type == PNG_COLOR_TYPE_PALETTE)
 		png_set_filler(png, 0xFF, PNG_FILLER_AFTER);
 
-	if(color_type == PNG_COLOR_TYPE_GRAY || color_type == PNG_COLOR_TYPE_GRAY_ALPHA)
+	if (color_type == PNG_COLOR_TYPE_GRAY
+			|| color_type == PNG_COLOR_TYPE_GRAY_ALPHA)
 		png_set_gray_to_rgb(png);
 
 	png_read_update_info(png, info);
 
-	row_pointers = (png_bytep*)malloc(sizeof(png_bytep) * height);
-	for(y = 0; y < height; y++) {
-		row_pointers[y] = (png_byte*)malloc(png_get_rowbytes(png,info));
+	row_pointers = (png_bytep*) malloc(sizeof(png_bytep) * height);
+	for (y = 0; y < height; y++) {
+		row_pointers[y] = (png_byte*) malloc(png_get_rowbytes(png, info));
 	}
 
 	png_read_image(png, row_pointers);
 
 	fclose(f);
-	
-	if (bit_depth == 16){			//in 16-bit: it is stored as RRGGBB
-		for (y=0; y<height; y++) {
+
+	if (bit_depth == 16) {			//in 16-bit: it is stored as RRGGBB
+		for (y = 0; y < height; y++) {
 			png_byte* row = row_pointers[y];
-			for (x=0; x<width; x++) {
-				png_byte* ptr = &(row[x*8]);
-				*buf[RLAYER]++ = ptr[0]*(UCHAR_MAX+1)+ptr[1];
-				*buf[GLAYER]++ = ptr[2]*(UCHAR_MAX+1)+ptr[3];
-				*buf[BLAYER]++ = ptr[4]*(UCHAR_MAX+1)+ptr[5];	
+			for (x = 0; x < width; x++) {
+				png_byte* ptr = &(row[x * 8]);
+				*buf[RLAYER]++ = ptr[0] * (UCHAR_MAX + 1) + ptr[1];
+				*buf[GLAYER]++ = ptr[2] * (UCHAR_MAX + 1) + ptr[3];
+				*buf[BLAYER]++ = ptr[4] * (UCHAR_MAX + 1) + ptr[5];
 			}
 		}
-	}
-	else{
-		for (y=0; y<height; y++) {
+	} else {
+		for (y = 0; y < height; y++) {
 			png_byte* row = row_pointers[y];
-			for (x=0; x<width; x++) {		
-				png_byte* ptr = &(row[x*4]);
+			for (x = 0; x < width; x++) {
+				png_byte* ptr = &(row[x * 4]);
 				*buf[RLAYER]++ = ptr[0];
 				*buf[GLAYER]++ = ptr[1];
 				*buf[BLAYER]++ = ptr[2];
 			}
 		}
 		fit->bitpix = BYTE_IMG;
-	}	
+	}
 	// We define the number of channel we have
-	switch(color_type){
+	switch (color_type) {
 	case PNG_COLOR_TYPE_RGB_ALPHA:
 	case PNG_COLOR_TYPE_RGB:
-		nbplanes=3;
+		nbplanes = 3;
 		break;
 	case PNG_COLOR_TYPE_GRAY_ALPHA:
 	case PNG_COLOR_TYPE_GRAY:
-		nbplanes=1;
+		nbplanes = 1;
 		break;
 	default:
-		nbplanes=0;	
+		nbplanes = 0;
 	}
-	
+
 	// free allocated memory
-	for (y=0; y<height; y++)
+	for (y = 0; y < height; y++)
 		free(row_pointers[y]);
 	free(row_pointers);
-	
-	if (data != NULL){
+
+	if (data != NULL) {
 		clearfits(fit);
 		fit->rx = width;
 		fit->ry = height;
 		fit->naxes[0] = width;
 		fit->naxes[1] = height;
 		fit->naxes[2] = nbplanes;
-		if (nbplanes==1)
+		if (nbplanes == 1)
 			fit->naxis = 2;
 		else
 			fit->naxis = 3;
@@ -684,19 +686,13 @@ int readpng(const char *name, fits* fit) {
 	mirrorx(fit, FALSE);
 	gchar *basename = g_path_get_basename(name);
 	siril_log_message(_("Reading PNG: %d-bit file %s, %ld layer(s), %ux%u pixels\n"),
-						bit_depth, basename, fit->naxes[2], fit->rx, fit->ry);
+			bit_depth, basename, fit->naxes[2], fit->rx, fit->ry);
 	g_free(basename);
 
 	return nbplanes;
 }
 
 /* Code borrowed from SER Player */
-// Support as many libpng versions as required
-#if PNG_LIBPNG_VER_MAJOR==2
-#error "libpng 2.x.x is not supported"
-#elif PNG_LIBPNG_VER_MAJOR==1 && PNG_LIBPNG_VER_MINOR==7
-#error "libpng 1.7.x is not supported"
-#elif PNG_LIBPNG_VER_MAJOR==1 && PNG_LIBPNG_VER_MINOR==6
 
 // ------------------------------------------
 // Save PNG image (colour)
@@ -763,48 +759,6 @@ static int32_t save_mono_file(const char *filename, const WORD *p_image_data,
 	return ret;
 }
 
-#elif PNG_LIBPNG_VER_MAJOR==1 && PNG_LIBPNG_VER_MINOR==5
-#error "libpng 1.5.x is not supported"
-#elif PNG_LIBPNG_VER_MAJOR==1 && PNG_LIBPNG_VER_MINOR==4
-#error "libpng 1.4.x is not supported"
-#elif PNG_LIBPNG_VER_MAJOR==1 && PNG_LIBPNG_VER_MINOR==3
-#error "libpng 1.3.x is not supported"
-#elif PNG_LIBPNG_VER_MAJOR==1 && PNG_LIBPNG_VER_MINOR==2
-
-// ------------------------------------------
-// Save PNG image (colour)
-// ------------------------------------------
-static int32_t save_colour_file(
-		const char *filename,
-		const WORD *p_image_data,
-		uint32_t width,
-		uint32_t height,
-		uint32_t bytes_per_sample)
-{
-	int32_t ret = -1;
-
-	return ret;
-}
-
-// ------------------------------------------
-// Save PNG image (mono B, G or R)
-// ------------------------------------------
-static int32_t save_mono_file(
-		const char *filename,
-		const WORD *p_image_data,
-		uint32_t width,
-		uint32_t height,
-		uint32_t bytes_per_sample)
-{
-	int32_t ret = -1;
-
-	return ret;
-}
-
-#else
-#error "Unsuported libpng version"
-#endif
-
 static WORD *fits_to_bgrbgr(fits *image) {
 	int ndata = image->rx * image->ry;
 	int i, j;
@@ -840,6 +794,9 @@ int savepng(const char *name, fits *fit, uint32_t bytes_per_sample,
 		ret = save_mono_file(filename, fit->data, width, height,
 				bytes_per_sample);
 	}
+	siril_log_message(_("Saving PNG: file %s, %ld layer(s), %ux%u pixels\n"),
+			filename, fit->naxes[2], fit->rx, fit->ry);
+
 	free(filename);
 	return ret;
 }
@@ -850,10 +807,27 @@ int savepng(const char *name, fits *fit, uint32_t bytes_per_sample,
 #ifdef HAVE_LIBRAW
 
 static void get_FITS_date(time_t date, char *date_obs) {
-	struct tm *t = gmtime(&date);
-	g_snprintf(date_obs, FLEN_VALUE, "%04d-%02d-%02dT%02d:%02d:%02d",
-			t->tm_year + 1900, t->tm_mon + 1, t->tm_mday, t->tm_hour, t->tm_min,
-			t->tm_sec);
+	struct tm *t;
+#ifdef HAVE_GMTIME_R
+	struct tm t_;
+#endif
+
+#ifdef _WIN32
+	t = gmtime (&date);
+#else
+#ifdef HAVE_GMTIME_R
+	t = gmtime_r (&date, &t_);
+#else
+	t = gmtime(&date);
+#endif /* HAVE_GMTIME_R */
+#endif /* _WIN32 */
+
+	/* If the gmtime() call has failed, "secs" is too big. */
+	if (t) {
+		g_snprintf(date_obs, FLEN_VALUE, "%04d-%02d-%02dT%02d:%02d:%02d",
+				t->tm_year + 1900, t->tm_mon + 1, t->tm_mday, t->tm_hour, t->tm_min,
+				t->tm_sec);
+	}
 }
 
 #if defined(_WIN32) && (defined(__MINGW32__) || !defined(_MSC_VER) || (_MSC_VER <= 1310))
@@ -1080,9 +1054,36 @@ static int readraw(const char *name, fits *fit) {
 	return nbplanes;
 }
 
-#define FC(filters, row,col) \
+#define FC(filters, row, col) \
 	(filters >> ((((row) << 1 & 14) + ((col) & 1)) << 1) & 3)
 
+static const char filter[16][16] =
+{ { 2,1,1,3,2,3,2,0,3,2,3,0,1,2,1,0 },
+  { 0,3,0,2,0,1,3,1,0,1,1,2,0,3,3,2 },
+  { 2,3,3,2,3,1,1,3,3,1,2,1,2,0,0,3 },
+  { 0,1,0,1,0,2,0,2,2,0,3,0,1,3,2,1 },
+  { 3,1,1,2,0,1,0,2,1,3,1,3,0,1,3,0 },
+  { 2,0,0,3,3,2,3,1,2,0,2,0,3,2,2,1 },
+  { 2,3,3,1,2,1,2,1,2,1,1,2,3,0,0,1 },
+  { 1,0,0,2,3,0,0,3,0,3,0,3,2,1,2,3 },
+  { 2,3,3,1,1,2,1,0,3,2,3,0,2,3,1,3 },
+  { 1,0,2,0,3,0,3,2,0,1,1,2,0,1,0,2 },
+  { 0,1,1,3,3,2,2,1,1,3,3,0,2,1,3,2 },
+  { 2,3,2,0,0,1,3,0,2,0,1,2,3,0,1,0 },
+  { 1,3,1,2,3,2,3,2,0,2,0,1,1,0,3,0 },
+  { 0,2,0,3,1,0,0,1,1,3,3,2,3,2,2,1 },
+  { 2,1,3,2,3,1,2,1,0,3,0,2,0,2,0,2 },
+  { 0,3,1,0,0,2,0,3,2,1,3,1,1,3,1,3 } };
+
+static int fcol(libraw_data_t *raw, int row, int col) {
+	if (raw->idata.filters == 1)
+		return filter[(row + raw->rawdata.sizes.top_margin) & 15][(col
+				+ raw->rawdata.sizes.left_margin) & 15];
+	if (raw->idata.filters == 9)
+		return raw->idata.xtrans[(row + 6) % 6][(col + 6) % 6];
+	return FC(raw->idata.filters, row, col);
+}
+
 static int readraw_in_cfa(const char *name, fits *fit) {
 	libraw_data_t *raw = libraw_init(0);
 	unsigned int i, j, c, col, row;
@@ -1151,18 +1152,15 @@ static int readraw_in_cfa(const char *name, fits *fit) {
 			fhigh = 4;
 		if ((filters ^ (filters >> 16)) & 0xffff)
 			fhigh = 8;
-		if ((filters == 1) /* Leaf Catchlight with 16x16 bayer matrix */
-				|| (filters == 9)) /* Fuji X-Trans (6x6 matrix) */ {
-			siril_log_message(_("This kind of RAW pictures is not supported.\n"));
-			libraw_recycle(raw);
-			libraw_close(raw);
-			return -1;
-		}
+		if (filters == 1) /* Leaf Catchlight with 16x16 bayer matrix */
+			fhigh = fwide = 16;
+		if (filters == 9) /* Fuji X-Trans (6x6 matrix) */
+			fhigh = fwide = 6;
 
 		j = 0;
 		for (i = 0; i < fhigh; i++) {
-			for (c = i && 0; c < fwide; c++) {
-				pattern[j++] = raw->idata.cdesc[FC(filters, i, c)];
+			for (c = i /*&& (pattern[j++] = '/')*/ && 0; c < fwide; c++) {
+				pattern[j++] = raw->idata.cdesc[fcol(raw, i, c)];
 			}
 		}
 		pattern[j++] = '\0';
