@@ -1474,7 +1474,7 @@ proper_ending:
 /* process PSF for the given sequence, on the given layer, the area of the
  * image selection (com.selection), as a threaded operation or not.
  */
-int seqpsf(sequence *seq, int layer, gboolean for_registration,
+int seqpsf(sequence *seq, int layer, gboolean for_registration, gboolean regall,
 		framing_mode framing, gboolean run_in_thread) {
 
 	if (framing == REGISTERED_FRAME && !seq->regparam[layer])
@@ -1500,8 +1500,8 @@ int seqpsf(sequence *seq, int layer, gboolean for_registration,
 	args->layer_for_partial = layer;
 	args->regdata_for_partial = framing == REGISTERED_FRAME;
 	args->get_photometry_data_for_partial = !for_registration;
-	args->filtering_criterion = seq_filter_included;
-	args->nb_filtered_images = seq->selnum;
+	args->filtering_criterion = (regall == TRUE) ? seq_filter_all : seq_filter_included;
+	args->nb_filtered_images = (regall == TRUE) ? seq->number : seq->selnum;
 	args->prepare_hook = NULL;
 	args->finalize_hook = NULL;
 	args->image_hook = seqpsf_image_hook;
