@@ -55,7 +55,7 @@ gboolean sequence_is_rgb(sequence *seq);
 imstats* seq_get_imstats(sequence *seq, int index, fits *the_image, int option);
 void	enforce_area_in_image(rectangle *area, sequence *seq);
 
-int seqpsf(sequence *seq, int layer, gboolean for_registration,
+int seqpsf(sequence *seq, int layer, gboolean for_registration, gboolean regall,
 		framing_mode framing, gboolean run_in_thread);
 
 /* in export.c now */
