@@ -61,14 +61,15 @@ struct ser_struct {
 	int image_height;		// 4	(30)
 	int bit_pixel_depth;		// 4	(34)
 	unsigned int frame_count;	// 4	(38)
-	char observer[40];			// 40	(42)
+	char observer[40];		// 40	(42)
 	char instrument[40];		// 40	(82)
 	char telescope[40];		// 40	(122)
-	uint64_t date;	// 8	(162)
+	uint64_t date;		// 8	(162)
 	uint64_t date_utc;	// 8 (170)
 
 	/* timestamps (not in the header, timestamps are in trailer) */
 	uint64_t *ts;			// total timestamps
+	int ts_alloc;			// allocated number of elements in ts
 	uint64_t ts_min, ts_max;// min and max timestamp
 	double fps;				// frame rate
 
@@ -80,18 +81,20 @@ struct ser_struct {
 	int fd;
 	char *filename;
 #ifdef _OPENMP
-	omp_lock_t fd_lock;
+	omp_lock_t fd_lock, ts_lock;
 #endif
 };
 
 void ser_convertTimeStamp(struct ser_struct *ser_file, GSList *timestamp);
 void ser_init_struct(struct ser_struct *ser_file);
 void ser_display_info(struct ser_struct *ser_file);
-int ser_open_file(char *filename, struct ser_struct *ser_file);
+int ser_open_file(const char *filename, struct ser_struct *ser_file);
 int ser_write_and_close(struct ser_struct *ser_file);
 int ser_create_file(const char *filename, struct ser_struct *ser_file, gboolean overwrite, struct ser_struct *copy_from);
 int ser_close_file(struct ser_struct *ser_file);
 int ser_read_frame(struct ser_struct *ser_file, int frame_no, fits *fit);
+int ser_read_opened_partial_fits(struct ser_struct *ser_file, int layer,
+		int frame_no, fits *fit, const rectangle *area);
 int ser_read_opened_partial(struct ser_struct *ser_file, int layer,
 		int frame_no, WORD *buffer, const rectangle *area);
 int ser_write_frame_from_fit(struct ser_struct *ser_file, fits *fit, int frame);
