@@ -110,7 +110,7 @@ int read_single_image(const char* filename, fits *dest, char **realname_out) {
 	retval = stat_file(filename, &imagetype, &realname);
 	if (retval) {
 		char *msg = siril_log_message(_("Error opening image %s: file not found or not supported.\n"), filename);
-		show_dialog(msg, _("Error"), "gtk-dialog-error");
+		show_dialog(msg, _("Error"), "dialog-error");
 		set_cursor_waiting(FALSE);
 		free(realname);
 		return 1;
@@ -153,11 +153,11 @@ int open_single_image(const char* filename) {
 		return 0;
 	}
 	if (retval == 2) {
-		show_dialog(_("This file could not be opened because its extension is not supported.\n"), _("Error"), "gtk-dialog-error");
+		show_dialog(_("This file could not be opened because its extension is not supported.\n"), _("Error"), "dialog-error");
 		return 1;
 	}
 	if (retval == 1) {
-		show_dialog(_("There was an error when opening this image. See the log for more information."), _("Error"), "gtk-dialog-error");
+		show_dialog(_("There was an error when opening this image. See the log for more information."), _("Error"), "dialog-error");
 		return 1;
 	}
 
