@@ -4,7 +4,6 @@
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
-#ifdef HAVE_OPENCV
 
 #ifdef __cplusplus
 extern "C" {
@@ -13,6 +12,8 @@ extern "C" {
 #include <stdint.h>
 #include "registration/matching/misc.h"
 #include "registration/matching/atpmatch.h"
+#include "gui/progress_and_log.h"
+
 
 int cvResizeGaussian(fits *, int, int, int);
 int cvResizeGaussian_data8(uint8_t *dataIn, int rx, int ry, uint8_t *dataOut,
@@ -23,10 +24,9 @@ int cvCalculH(s_star *star_array_img,
 int cvTransformImage(fits *, point, Homography, int);
 int cvUnsharpFilter(fits*, double, double);
 int cvComputeFinestScale(fits *image);
+int cvLucyRichardson(fits *image, double sigma, int iterations);
 #ifdef __cplusplus
 }
 #endif
 
-#endif	/* HAVE_OPENCV */
-
 #endif
