@@ -413,7 +413,7 @@ int register_shift_fwhm(struct registration_args *args) {
 	if (args->follow_star)
 		framing = FOLLOW_STAR_FRAME;
 
-	if (seqpsf(args->seq, args->layer, TRUE, framing, FALSE))
+	if (seqpsf(args->seq, args->layer, TRUE, args->process_all_frames, framing, FALSE))
 		return 1;
 
 	current_regdata = args->seq->regparam[args->layer];
@@ -1157,7 +1157,7 @@ void on_seqregister_button_clicked(GtkButton *button, gpointer user_data) {
 			&& method->sel != REQUIRES_NO_SELECTION) {
 		msg = siril_log_message(
 				_("All prerequisites are not filled for registration. Select a rectangle first.\n"));
-		show_dialog(msg, _("Warning"), "gtk-dialog-warning");
+		show_dialog(msg, _("Warning"), "dialog-warning");
 		return;
 	}
 	// TODO: check for reentrance
@@ -1190,7 +1190,7 @@ void on_seqregister_button_clicked(GtkButton *button, gpointer user_data) {
 		double diff = test_available_space(size * 4.0); //FIXME: 4 is only ok for x2 Drizzle
 		if (diff < 0.0) {
 			msg = siril_log_message(_("Not enough disk space to perform Drizzle operation !!\n"));
-			show_dialog(msg, _("Error"), "gtk-dialog-error");
+			show_dialog(msg, _("Error"), "dialog-error");
 			free(reg_args);
 			return;
 		}
